@@ -241,7 +241,8 @@ class OperationModel(object):
 
     @CachedProperty
     def can_paginate(self):
-        return self._operation_data.get("x-paginates", False)
+        # A valid paginating operation always has x-paging-default-max-items
+        return "x-paging-default-max-items" in self._operation_data
 
     @CachedProperty
     def paging_input_token(self):
@@ -281,6 +282,12 @@ class OperationModel(object):
             return int(self._operation_data.get("x-paging-default-max-items"))
         return None
 
+    @CachedProperty
+    def form_factors(self):
+        if "x-form-factors" in self._operation_data:
+            return self._operation_data['x-form-factors'].split(',')
+        return None
+
     @CachedProperty
     def input_shape(self):
         return self._service_model.resolve_shape_ref(
@@ -345,6 +352,10 @@ class ServiceModel(object):
     def products(self):
         return self._service_data.get("x-products", "ALTUS").split(',')
 
+    @CachedProperty
+    def form_factors(self):
+        return self._service_data.get("x-form-factors", "public").split(',')
+
 
 class DenormalizedStructureBuilder(object):
     """Build a StructureShape from a denormalized model.
